@@ -211,7 +211,7 @@ class TestCreateMachine(object):
     COMMAND_WITH_OPTIONS_FILE = ["machines", "create", "--optionsFile", ]  # path added in test
 
     EXPECTED_STDOUT = "New machine created with id: psclbvqpc\n" \
-                      "https://www.paperspace.com/console/machines/psclbvqpc\n"
+                      "https://console.paperspace.com/machines/psclbvqpc\n"
 
     RESPONSE_JSON_WITH_WRONG_API_TOKEN = {"status": 400, "message": "Invalid API token"}
     EXPECTED_STDOUT_WITH_WRONG_API_TOKEN = "Failed to create resource: Invalid API token\n"
